=============
SQL Functions
=============


.. raw:: html

    <style>
      div.sd-card-body.docutils li.toctree-l1 > :first-child {display: none;}
    </style>


.. grid::

    .. grid-item-card::

        **Aggregate**
        ^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           aggregate

    .. grid-item-card::

        **Array**
        ^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           array

    .. grid-item-card::

        **Conditional**
        ^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           conditional

    .. grid-item-card::

        **Mathematical**
        ^^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           math

.. grid::

    .. grid-item-card::

        **String**
        ^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           string

    .. grid-item-card::

        **Temporal**
        ^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           temporal

    .. grid-item-card::

        **Trigonometry**
        ^^^^^^^^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           trigonometry

    .. grid-item-card::

        **Types**
        ^^^^^^^^^

        .. toctree::
           :maxdepth: 2

           types
